* {
    padding: 0;
    margin: 0;
} 

body {
    background:white url("../img/fond1.gif") repeat-x top left;
    font-family: Verdana, Arial, Helvetica, sans-serif;
    font-size:90%;
}
a{
    color: #d021d8;
}
a:hover{
    color: blue;
}
a img{
    border:none;
}
h1{
    font-family: "Trebuchet MS", Arial, Helvetica, sans-serif;
    font-size:180%;
    font-weight:bold !important;
    margin:10px 0;
    padding-bottom:5px;
}
h2{
    font-family: "Trebuchet MS", Arial, Helvetica, sans-serif;
    font-size:150%;
    font-weight:bold !important;
    margin:10px 0;
    padding-bottom:5px;
}

h3{
    font-family: "Trebuchet MS", Arial, Helvetica, sans-serif;
    font-size:130%;
    margin:10px 0;
    padding-bottom: 5px;

}
#static_content p{
    padding-bottom:10pt !important;
    font-size:110%;
    line-height:20pt;
}
#static_content img{
    margin-left:2%;
    border:1px solid #ccc;
    padding:3px;
    background-color:#efefef;
}
/*********************************/
header{
    display:block;
    width:990px;
    margin:0 auto;
    height:60px;
}
header img{
    width:150px;
    margin-top:10px;
    MARGIN-LEFT:10PX;
    float:left;
}
.tagline{
    color:white;
    padding-top:28px;
    display:block;
    width:320px;
    float:left;
    margin-left:10px;
    text-shadow:0 1px 1px #AE1BB4;
}

#utils{
    float:right;
    margin-top:25px;
    font-size:80%;
}
#utils a{
    color:white;
    text-decoration:none;
    float:right;
    margin-left:0.8em;
    padding:5px 8px;
    border-radius:5px;
    -moz-border-radius:5px;
    -webkit-border-radius:5px;
    behavior: url("/static/css/PIE.htc");
    background-color:#AE1BB4;
    text-shadow: 0 0 10px white;

}
#utils a:hover{
    background-color:#CD21D5;
    text-decoration:none !important;

}
#utils form{
    float:left;
}
#utils label{
    color:white;
}
#utils a:hover{
    text-decoration:underline;
}
#utils form{
    color:#4f0952;
    color:#2f0431;
    text-transform:uppercase;
    margin-top:3px;
    letter-spacing:0.8pt;
    font-size:90%;

}
#utils #q{
    border:1px solid #AE1BB4;
    line-height:24px;
}

#placeform{
    background-color: #efefef;
    border-radius: 10px;
    margin-top: 10px;
    padding: 10px 30px 40px;
}

#placeform label {
    display: block;
    float: left;
    margin-right: 10px;
    text-align: right;
    width: 80px;
}

#placeform p, #map_container {
    padding-bottom: 15px;
}

#placeform input.submit {
    background-color: #d021d8;
    border: medium none;
    border-radius: 5px;
    box-shadow: 0 2px 5px rgba(0, 0, 0, 0.698);
    color: white;
    cursor: pointer;
    margin-left: 85px;
    margin-top: 10px;
    padding: 5px;
    position: relative;
    text-transform: uppercase;
}

#placeform span{
    margin-left: 85px;
}
#placeform span.required{
    margin-left:10px;
    font-size:80%;
    color:red;
}
.btn-primary {
    background-color: #d021d8;
    border: medium none;
    border-radius: 5px;
    box-shadow: 0 2px 5px rgba(0, 0, 0, 0.698);
    color: white;
    cursor: pointer;
    padding: 5px;
    position: relative;
    text-transform: uppercase;
    text-decoration:none;
}
/*********myplace*************/
form table{
    margin-top:20px;
    width:100%;
}
form table input, form table select{
    height:25px;
    border:1px solid #ccc;
}
form table thead td{
    background-color:#efefef;
}
form table input.btn-primary{
    width:auto;
}
form table th{
    background-color:#ccc;
    padding:5px;
}
form table td{
    padding:5px;
}
form table tbody td{
    border:1px solid #efefef;
}
.hsearchbutton{
    background-color:#efefef;
    border:1px solid #ccc;

    padding:3px 5px 2px 5px;
    cursor:pointer;
    text-transform:uppercase;
    letter-spacing:0.8pt;
    font-size:90%;
    border-radius:5px;
    -moz-border-radius:5px;
    -webkit-border-radius:5px;
    behavior: url("/static/css/PIE.htc");
    position:relative;
}

.hsearchbutton:hover{
    box-shadow:0 0 8px rgba(0,0,0,0.3) inset;
    -moz-box-shadow:0 0 8px rgba(0,0,0,0.3) inset;
    -webkit-box-shadow:0 0 8px rgba(0,0,0,0.3) inset;
    background-color:#ccc;
    behavior: url("/static/css/PIE.htc");
    position:relative;
}



#maincontainer{
    width:990px;
    margin:0 auto;
}
#mainmenu{
    height:102px;
    margin-left:10px;
    width:970px;
}
#mainmenu form{
    text-align:center;
    padding:30px 0 0 0;
    font-weight:bold;
}


#mainmenu #q{
    width:400px;
    height:25px;
    padding-bottom:5px;
    border:1px solid #ccc;
    border-color:#efefef #ccc #ccc #efefef;
}
.searchbutton{
    background:url("../img/botoisearch.png") no-repeat top left;
    padding:5px 15px 32px 15px;
    border:none;
    position:absolute;
    font-size:14px;
    display:inline-block;
    width:68px;
}

.searchbutton:hover{
    background:url("../img/botoisearch_on.png") no-repeat top left;
    cursor:pointer;
}
#bigsf p{
    font-size: 80%;
    font-weight: normal;
    padding-left: 310px;
    padding-top: 5px;
    text-align: left;
}

#maincontent{
    box-shadow:0 0 15px rgba(204,204,204,1);
    -moz-box-shadow:0 0 15px rgba(204,204,204,1);
    -webkit-box-shadow:0 0 15px rgba(204,204,204,1);
    behavior: url("/static/css/PIE.htc");
    padding:20px 35px;
    font-size:90%;
    float:left;
    width:920px;
    position:relative;
    background-color:white;
}
#tpl_about #locacol1 p{
    margin-bottom:10px;
    line-height:18pt;
}
#userinfo{
    position:absolute;
    top:-2px;
    right:10px;
    background-color:#CD21D5;
    background-color:#3a3a3a;
    border-radius:0 0 8px 8px;
    -moz-border-radius:0 0 8px 8px;
    -webkit-border-radius:0 0 8px 8px;
    padding:4px 45px 4px 10px;
    padding:4px 10px 4px 10px;
    box-shadow:0 5px 5px rgba(0,0,0,0.5);
    -moz-box-shadow:0 5px 5px rgba(0,0,0,0.5);
    -webkit-box-shadow:0 5px 5px rgba(0,0,0,0.5);
    behavior: url("/static/css/PIE.htc");
    color:white;
    white-space:nowrap;

}
#userinfo img{
    width:25px;
    float:left;
    margin-right:5px;
    border:1px solid #999;
}
#userinfo a{
    color:#efefef !important;
    text-decoration:none;
    border-bottom:1px solid #d021d8;
}
#useroptionsname{
    padding-top:5px;
    padding-left:35px;
}
#userinfo a:hover{
    color:#d021d8 !important;
    text-decoration:none;
}
#breadcrumb{
    font-size:90%;
    margin-bottom:20px;
}
/**********************mainmenu*********************/
#menu1{
    font-size: 90%;
    padding-bottom: 10px;
    padding-top: 35px;
    border-bottom: 1px solid #EFEFEF;
}
#menu1 li{
    display:inline;
}
#menu2{

    font-size: 90%;
    padding-top: 10px;
}
#menu2 li{
    display:inline;
}

#menu1 a{
    text-decoration:none;
    padding:10px 30px 10px 15px;
    color:black !important;
    border-left:1px solid #EFEFEF;
    background: url("../img/menu1.gif") no-repeat top right;
    border-left:1px solid #D9D9D9;

}
#menu1 a:hover{
    background: url("../img/menu1_on.gif") no-repeat top right;
    border-left:1px solid #D9D9D9;
}
#menu1 .selected a{
    background: url("../img/menu1_on.gif") no-repeat top right;
    border-left:1px solid #D9D9D9;
}
#menu2 a{
    text-decoration:none;
    color:#666;
    padding:10px 20px;
    border-right:1px solid #efefef !important;
}
#menu2 a:hover{
    background-color:#efefef;
}
#menu2 .selected a{
    background-color:#efefef;
}
/********portada**********/
#homemap{
    width:450px;
    float:left !important;

}
#homefeatured{
    width:420px;
    float:right;
    
}
#appbadges{
    margin-top:0.5em;
    margin-bottom:1.5em;
}
#appbadges img{
    max-height:40px;
    width:auto !important;
}
#appbadges a{
    text-decoration:none;
}
#provinces, #cities{
   list-style-image:none;
   list-style:none;
}
#provinces {
    width:30%;
    float:left;
}
#cities{
    width:60%;
    float:left;
    margin-left:4%;
}

#provinces li a, #cities li a{
    font-family: "Trebuchet MS", Arial, Helvetica, sans-serif;
    padding-top:3px;
    color:white;
    background: url("../img/botoikapi.gif") no-repeat top left;
    font-size:100%;
    font-weight:bold;
    height:33px;
    text-align:center;
    text-decoration:none;
    display:block;
    margin-right:4px;
    margin-bottom:10px;
    width:130px;
    text-shadow: 0 0 10px #333;
}
#provinces li a{
    font-size:110%;
    font-weight:bold;
    text-shadow: 0 0 10px #A311AA;
    letter-spacing:1px;

}
#cities li a{
     background: url("../img/botoiprobintzi.gif") no-repeat top left;
    width:170px;
}
#provinces li a:hover{
    background: url("../img/botoikapi_on.gif") no-repeat top left;
}
#cities li a:hover{
     background: url("../img/botoiprobintzi_on.gif") no-repeat top left;
}
#homefeatured h3{
    margin-top:20px;
}
.itemlist{
    list-style-image:none;
   list-style:none;
   margin-right:20px;
}
.itemlist li{
    background:#f5f5f5 url("../img/fonditem.gif") repeat-x top left;
    height:50px;
    padding:10px 10px 15px 10px;
    margin-bottom:5px;
}
.listicon{
    float:left;
    margin-right:10px;
}
.access{
    float:right;
    margin-top:-10px;
}
/***********herrika***************/
.locationlist{
    width:22%;
    float:left;
    margin-left:2%;
}
.locationlist li{
    margin-bottom:5px;
}
.locationlist a{
    font-size:110%;
    text-decoration:none;
    display:block;
}
.locationlist a:hover{
    background-color:#d021d8;
    color:white;
}
/************herria****************/
.returnlink{
    margin-bottom:15px;
    background: url("../img/back.gif") no-repeat 0 5px;
    padding-left:15px;
}
#locacol1{
    width:50%;
    float:left; 
}
#locacol2{
    width:48%;
    float:right;      
}
/******************puntua*********************/
body#tpl_place{
    background:white url("../img/fond2.gif") repeat-x top left;    
}
body#tpl_place #mainmenu{
    height:25px;
}
#placecol1{
    width:50%;
    float:left;
}
#placecol2{
    width:48%;
    float:right;   
}
.mainicon{
    float:left;
    margin-right:10px;
}
.placethumb{
    padding:4px;
    background-color:#efefef;
    float:left;
    margin:0 10px 10px 35px;
}
#placecol1 h1{
    margin-bottom:0;
}
.category_name{
    margin-left:35px;
    margin-bottom:20px;
    font-weight:bold;
    text-transform:uppercase;
    color:gray;
    font-size:90%;
    text-shadow: 0 1px 1px #ccc;
}
#placecol1 address{
    margin-bottom:20px;
    font-size:110%;
    color:gray;
    margin-left:35px;
}
.access_definition {
    width: 29px;
    height: 29px;
    text-indent: -2000px;
    float:left;
    background: url("../icn/accessicons.png") no-repeat top left;
    margin-right:3px;
}
#access{
    padding:8px 8px 15px 8px;
    margin-top:20px;
    color:#333;
    box-shadow: 0 0 10px rgba(204,204,204,1) inset;
    -moz-box-shadow:0 0 10px rgba(204,204,204,1) inset;
    -webkit-box-shadow:0 0 10px rgba(204,204,204,1) inset;
    behavior: url("/static/css/PIE.htc");
    width:97%;
    clear:both;
    border:1px solid #ddd;
}
#biblio{
    clear:left;
    padding:8px 8px 15px 8px;
    margin-top:10px;
    background-color:#efefef;
    position:relative;
    color:#333;
    box-shadow: 0 0 10px rgba(204,204,204,1) inset;
    -moz-box-shadow:0 0 10px rgba(204,204,204,1) inset;
    -webkit-box-shadow:0 0 10px rgba(204,204,204,1) inset;
    behavior: url("/static/css/PIE.htc");
    line-height:20px;
    float:left;
    margin-bottom:20px;
    width:97%;

}
#access h3, #biblio h3{
    margin-top:0;
    font-family:verdana;
    padding:5px 5px 5px 10px;
    border-bottom:1px dotted #999;
    font-weight:normal;
}
dl.accesstext{
    margin-bottom:10px;
    line-height:20px;
}
dl.accesstext dt{
    float:left;
    font-weight:bold;
    margin-right:10px;
    clear:left;
}
#biblio dt{
    float:left;
    margin-right:10px;
    clear:left;
    font-weight:bold;
    clear:both;
}
#biblio dd{
    float:left;
}
#biblio dl, #access dl, #access p, #biblio p{
    margin-left:10px;
}
#placecol2 h4{
    font-weight:normal;
}
#placecol2 .access_definition {
    background: url("../icn/accessicons2.png") no-repeat scroll left top transparent;
    float: left;
    height: 15px;
    text-indent: -2000px;
    width: 15px;
    margin-right:3px;
}
#nearest{
    margin-top:20px;
}
#placecol2 h3{
    color:gray;
}

#imagelist h3{ 
    border-bottom:1px dotted black;
}

/******************komentarioak*********************/
#commentlist {
     margin-top:20px;   
}
#commentlist h3{
    background:url("../img/h4comment.gif") no-repeat bottom left;
    padding-bottom:30px;   
}
#comment_list{
    margin-top:2em;
}
.comment{
    clear:both;
    border-bottom:1px dotted #ccc;
    padding: 10px 0;
    margin-bottom:10px;
    float:left;
    width:95%;
    background-color:#efefef;
    border-radius:8px;
    -moz-border-radius:8px;
    -webkit-border-radius:8px;
    padding:8px;
    behavior: url("/static/css/PIE.htc");
}
#communityform label{
    width:auto !important;
}
.helptext{
    clear:both;
    font-size:80%;
    display:block;
    font-style: italic;
    color:#333;
}
.commentimg{
    float:left;
    width:20%;
}
.commenttxt{
    float:right;
    width:80%;
}
.username{
    font-weight:bold;
}
.date{
    color:#666;
    font-style:italic;
}
.addcomment{
    background:url("../img/addcomment.gif")no-repeat top left;
    background:url("../img/botoiprobintzi.gif")no-repeat top left;
    padding:5px 0 10px 0;
    text-decoration:none;
    display:block;
    width:170px;
    color:white;
    text-transform:uppercase;
    text-align:center;
    border:none !important;
}
.comment_form{
    margin-bottom:20px;
}

#commentlist p{
    margin-bottom:10px;
}
#commentlist label{
    width:120px;
    display:block;
    float:left;
}
#commentlist input, #commentlist textarea{
    border:1px solid #ccc;
}
#commentlist .botoia{
    color:white;
    background-color:#d021d8;
    border:none;
    padding:5px;
    margin-top:10px;
    border-radius:5px;
    -moz-border-radius:5px;
    -webkit-border-radius:5px;
    box-shadow:0 2px 5px rgba(0,0,0,0.7);
    -moz-box-shadow:0 2px 5px rgba(0,0,0,0.7);
    -webkit-box-shadow:0 2px 5px rgba(0,0,0,0.7);
    behavior: url("/static/css/PIE.htc");
    cursor:pointer;
    position:relative;
}
/*******************************login************************/
#sidebar{
    width:40%;
    float:right;
    margin-top:10px;
    background-color:#efefef;
    padding:10px 30px 40px 30px;
    border-radius:10px;
    -moz-border-radius:10px;
    -webkit-border-radius:10px;
    behavior: url("/static/css/PIE.htc");
    position:relative;
}
#logcnt h2, #logcnt h1{
    margin-top:30px;
    margin-bottom:15px;
    border-radius:5px;
    -moz-border-radius:5px;
    -webkit-border-radius:5px;
    padding:3px 5px;
    box-shadow:0 3px 5px rgba(0,0,0,0.2);
    -moz-box-shadow:0 3px 5px rgba(0,0,0,0.2);
    -webkit-box-shadow:0 3px 5px rgba(0,0,0,0.2);
    behavior: url("/static/css/PIE.htc");
    background-color:#efefef;
    position:relative;
}
#logcnt input.submit{
    color:white;
    background-color:#d021d8;
    border:none;
    padding:5px;
    margin-top:10px;
    border-radius:5px;
    -moz-border-radius:5px;
    -webkit-border-radius:5px;
    box-shadow:0 2px 5px rgba(0,0,0,0.7);
    -moz-box-shadow:0 2px 5px rgba(0,0,0,0.7);
    -webkit-box-shadow:0 2px 5px rgba(0,0,0,0.7);
    behavior: url("/static/css/PIE.htc");
    cursor:pointer;
    text-transform:uppercase;
    position:relative;
}
#logcnt{
    background-color:#efefef;
    padding:10px 30px 40px 30px;
    border-radius:10px;
    -moz-border-radius:10px;
    -webkit-border-radius:10px;
    behavior: url("/static/css/PIE.htc");
    width:43%;
    margin-right:2%;
    float:left;
    position:relative;
}
#sidebar h2{
    border-radius:5px;
    -moz-border-radius:5px;
    -webkit-border-radius:5px;
    padding:3px 5px;
    box-shadow:0 3px 5px rgba(0,0,0,0.2);
    -moz-box-shadow:0 3px 5px rgba(0,0,0,0.2);
    -webkit-box-shadow:0 3px 5px rgba(0,0,0,0.2);
    behavior: url("/static/css/PIE.htc");
    background-color:#efefef;
    position:relative;
}
#sidebar form{
    padding:20px;
}
#sidebar p, #logcnt p{
    padding-bottom:15px;
}
#sidebar ul{
    margin-left:30px;
    line-height:30px;
}
#id_username, #id_password{
    border:1px solid #666;
}
#sidebar label{
    width:75px;
    text-align:right;
    display:block;
    float:left;
    margin-right:10px;
}
#logcnt label{
    width:100px;
    text-align:right;
    display:block;
    float:left;
    margin-right:10px;
}
#sidebar input.submit{
    color:white;
    background-color:#d021d8;
    border:none;
    padding:5px;
    margin-top:10px;
    border-radius:5px;
    -moz-border-radius:5px;
    -webkit-border-radius:5px;
    box-shadow:0 2px 5px rgba(0,0,0,0.7);
    -moz-box-shadow:0 2px 5px rgba(0,0,0,0.7);
    -webkit-box-shadow:0 2px 5px rgba(0,0,0,0.7);
    behavior: url("/static/css/PIE.htc");
    cursor:pointer;
    text-transform:uppercase;
    margin-left:85px;
    position:relative;
}
#logcnt .tabs{
    margin-left:30px;
    line-height:30px;
}
#logcnt .botoia{
    color:white;
    background-color:#d021d8;
    border:none;
    padding:5px;
    margin-top:10px;
    border-radius:5px;
    -moz-border-radius:5px;
    -webkit-border-radius:5px;
    box-shadow:0 2px 5px rgba(0,0,0,0.7);
    -moz-box-shadow:0 2px 5px rgba(0,0,0,0.7);
    -webkit-box-shadow:0 2px 5px rgba(0,0,0,0.7);
    behavior: url("/static/css/PIE.htc");
    cursor:pointer;
    position:relative;
}
/****************Google Search************/

#advsearch{
    background-color:#efefef;
    padding:10px;
    margin:10px 0 10px 0;
}
#advsearch ul{
    margin:10px 0;
}
#advsearch ul li{
    display:inline-block;
    float:left;
    margin-right:10px;
    margin-bottom:10px;
}
#advsearch li label{
    float:left;
}
#advsearch select{
    font-size:90%;
    line-height:20px;
    margin-top:5px;
}

#advsearch input{
    color:white;
    background-color:#d021d8;
    border:none;
    padding:5px;
    margin-top:10px;
    border-radius:5px;
    -moz-border-radius:5px;
    -webkit-border-radius:5px;
    position:relative;
    display:block !important;
    clear:both;
    box-shadow:2px 2px 2px rgba(1,1,1,0.5), 0 2px 2px rgba(1,1,1,0.7) inset;
    -moz-box-shadow:2px 2px 2px rgba(1,1,1,0.5), 0 2px 2px rgba(1,1,1,0.7) inset;
    -webkit-box-shadow:2px 2px 2px rgba(1,1,1,0.5), 0 2px 2px rgba(1,1,1,0.7) inset;
    behavior: url("/static/css/PIE.htc");
    cursor:pointer;
    position:relative;
}
.frm_help{
    margin-top:20px;
}
/************************/

footer{
    display:block;
    width:910px;
    margin:0 auto;
    background:#C21ECA url("../img/footer.gif") repeat-x top left;
    box-shadow:0 15px 15px rgba(204,204,204,1);
    -moz-box-shadow:0 15px 15px rgba(204,204,204,1);
    -webkit-box-shadow:0 15px 15px rgba(204,204,204,1);
    behavior: url("/static/css/PIE.htc");
    border-top:1px solid #ccc;
    padding:20px 40px;
    color:white;
    font-size:90%;
    clear:both;
}
footer p{
    padding:10px 20px;
}

#footutils{
    text-align:right;
    font-family: "Trebuchet MS", Arial, Helvetica, sans-serif;
    text-shadow: 0 0 10px white;
}
#footutils p{
    padding:5px 20px 15px 20px;
}
#footutils a{
    text-decoration:none;
    padding:5px 10px;
}
#footutils a:hover{
    color:white;
    background-color:#d021d8;
    border-radius:5px;
    -moz-border-radius:5px;
    -webkit-border-radius:5px;
    behavior: url("/static/css/PIE.htc");
}
footer address{
    float:right;
    margin-top:-35px;
    margin-right:80px;
    border-left:1px dotted white;
    padding-left:30px;
}
.csattribution{
    border:1px solid red;
    clear:both;
}
/***********************************************/

.accessibility {
    float: right;
    margin-top:-2px;
}
.access_term {
    display: none;
}
.accessibility dl {
    position: relative;
}


.access_definition span{}

.aphysic_n {background-position: 0px 0px;}
.aphysic_a {background-position: 0px -29px;}
.aphysic_p {background-position: 0px -58px;}
.avisual_n {background-position: -29px 0px;}
.avisual_a {background-position: -29px -29px;}
.avisual_p {background-position: -29px -58px;}
.aaudio_n {background-position: -58px 0px;}
.aaudio_a {background-position: -58px -29px;}
.aaudio_p {background-position: -58px -58px;}
.aintelec_n {background-position: -87px 0px;}
.aintelec_a {background-position: -87px -29px;}
.aintelec_p {background-position: -87px -58px;}
.aorganic_n {background-position: -116px 0px;}
.aorganic_a {background-position: -116px -29px;}
.aorganic_p {background-position: -116px -58px;}

#placecol2 .aphysic_n {background-position: 0px 0px;}
#placecol2 .aphysic_a {background-position: 0px -15px;}
#placecol2 .aphysic_p {background-position: 0px -30px;}
#placecol2 .avisual_n {background-position: -15px 0px;}
#placecol2 .avisual_a {background-position: -15px -15px;}
#placecol2 .avisual_p {background-position: -15px -30px;}
#placecol2 .aaudio_n {background-position: -30px 0px;}
#placecol2 .aaudio_a {background-position: -30px -15px;}
#placecol2 .aaudio_p {background-position: -30px -30px;}
#placecol2 .aintelec_n {background-position: -45px 0px;}
#placecol2 .aintelec_a {background-position: -45px -15px;}
#placecol2 .aintelec_p {background-position: -45px -30px;}
#placecol2 .aorganic_n {background-position: -60px 0px;}
#placecol2 .aorganic_a {background-position: -60px -15px;}
#placecol2 .aorganic_p {background-position: -60px -30px;}

.aphysic_s, .avisual_s, .aaudio_s, .aintelec_s, .aorganic_s {display:none;}

