{% extends "base.html" %}
{% load i18n %}

{% block main_content %}

<div id="logcnt">
{% block cscontent %}
{% endblock %}
</div>
<div id="sidebar">
{% block cssidebar %}

{% endblock %}
</div>
<!-- End sidebar div -->

{% endblock %}