{% extends "base.html" %}
{% load i18n %}

{% block searchbox%}{% endblock %}

{% block main_content %} 
<div class="inner">

<h1>{% trans action %}: {{q}}</h1>

<!-- Put the following javascript before the closing </head> tag. -->
<script>
  (function() {
    var cx = '002318387713884704423:4pwcgf1wug4';
    var gcse = document.createElement('script');
    gcse.type = 'text/javascript'; 
    gcse.async = true;
    gcse.src = (document.location.protocol == 'https:' ? 'https:' : 'http:') +
        '//www.google.com/cse/cse.js?cx=' + cx;
    var s = document.getElementsByTagName('script')[0]; s.parentNode.insertBefore(gcse, s);
  })();
</script>

<!-- Place this tag where you want both of the search box and the search results to render -->
<gcse:search linkTarget='_self'></gcse:search>
      
{%endblock%}