{% load i18n %}
<!doctype html>
<html lang="en">
<head>
    <meta http-equiv="Content-type" content="text/html; charset=utf-8" />
    <title>{% block head_title %}{% endblock %}</title>
    <link rel="stylesheet" href="{{STATIC_URL}}css/global.css" />
    <!--[if IE]>
    <script src="http://html5shiv.googlecode.com/svn/trunk/html5.js"></script>
    <![endif]-->
    {% block extraheader %}
    {% endblock %}

<meta name="google-site-verification" content="QU6fy18f0ZFLUARiKUbdcBA438hPKSghkhtVE5j14Ps" />

<script type="text/javascript">
  var _gaq = _gaq || [];
  _gaq.push(['_setAccount', 'UA-36392146-1']);
  _gaq.push(['_trackPageview']);

  (function() {
    var ga = document.createElement('script'); ga.type = 'text/javascript'; ga.async = true;
    ga.src = ('https:' == document.location.protocol ? 'https://ssl' : 'http://www') + '.google-analytics.com/ga.js';
    var s = document.getElementsByTagName('script')[0]; s.parentNode.insertBefore(ga, s);
  })();
</script>

</head>

<body id="tpl_{{template_name}}" onload="initialize()">

<header>
    <a href="/">
      <img src="{{STATIC_URL}}img/armap_logoa.gif" alt="{% trans "Ararteko maps" %}" />
    </a>
    <span class="tagline">{% trans "Discover and share accessible places" %}</span>
    <div id="utils">
     {% for code,lang in LANGUAGES %}
       {% if code != LANGUAGE_CODE %}
          <a href="{% url 'set_lang' %}?language={{code}}&amp;next={{request.path}}">{{lang}}</a>
       {% endif %}
     {% endfor %}


      {% if not hidesearch %}
          <form method="get" action="{% url 'gsearch' %}">
              <input type="hidden" name="cx" value="002318387713884704423:4pwcgf1wug4" />
              <label for="q">{% trans "Go to..." %}</label> <input id="q" name="q" type="text" />
              <input type="submit" name="sa" value="{% trans "Search" %}" class="hsearchbutton" />
              <input type="hidden" name="cof" value="FORID:11" />
          </form>
          <script type="text/javascript" src="http://www.google.com/coop/cse/brand?form=searchbox_001098326678246934980%3Afr8fiqutrzm"></script>
      {% endif %}

      </div>
</header>

<div id="maincontainer">
<div id="mainmenu">


    <!-- mainmenu start -->
    {% block mainmenu %}

    {% endblock %}
    <!-- mainmenu end -->
</div>

<!-- main_content start -->
<div id="maincontent">
    <!-- userinfo start -->
    <div id="userinfo">
    {% include "useroptions.html" %}
    </div>
    <!-- userinfo end -->

    <!-- breadcrumb start -->
    {% block breadcrumb %}

    {% endblock %}
    <!-- breadcrumb end -->

    {% block main_content %}

    {% endblock %}
</div>
<!-- main_content end -->
</div>
<!-- main_container end -->

<footer>
    <div id="footutils">
        <p><a href="/pg/about/">{% trans "About the maps" %}</a> | <a href="/pg/accessibility/">{% trans "Accessibility" %}</a>
        <a href="/pg/privacy/">{% trans "Privacy" %}</a></p>
    </div>

<p>{% trans "Project supported by" %} <a href="http://www.ararteko.net/"><img src="{{STATIC_URL}}img/ararteko.gif" alt="Ararteko logo" /></a></p>

    <address>
        Prado 9<br />
        01005 Vitoria-Gasteiz<br />
        Tel: 945 13 51 18
    </address>
</footer>

</body>
</html>