{% load i18n %}

{% trans "access_a" %}
{% trans "access_p" %}
{% trans "access_n" %}
{% trans "access_s" %}


Servicios bibliotecas

{% trans "acceso_bbdd" %}
{% trans "prestamo" %}
{% trans "hemeroteca" %}
{% trans "consulta" %}
{% trans "wifi" %}
{% trans "reprografia" %}
{% trans "infor_bibliografica" %}
{% trans "prestamo_domic" %}
{% trans "internet_usuarios" %}
{% trans "prestamo_inter" %}
{% trans "bol_novedades" %}
{% trans "selectiva" %}
{% trans "infantil" %}
{% trans "seccion_local" %}
{% trans "comiteca" %}
{% trans "fondo_antiguo" %}
{% trans "formacion" %}
{% trans "sala_estudio" %}
{% trans "sala_investigacion" %}
{% trans "visitas_guiadas" %}
{% trans "publicaciones" %}
{% trans "audicion" %}

{% trans "mediateca" %}
{% trans "lectura_facil" %}
{% trans "seccion_xl" %}
{% trans "audiolibros" %}

{% trans "general" %}
{% trans "euskalkultura" %}
{% trans "especializada" %}
{% trans "musica" %}

{% trans "ayto" %}
{% trans "auto" %}
{% trans "priv" %}
{% trans "fora" %}

Tipo Biblio

{% trans "i" %}
{% trans "v" %}
{% trans "t" %}
{% trans "e" %}

Tipo de acceso

{% trans "l" %}
{% trans "r" %}

Tipo de centro:

{% trans "p" %}

{% trans "filter" %}
{% trans "search" %}


Fuentes de datos

{% trans "ejgv_biblio" %}
{% trans "ejgv-tur-rest" %}
{% trans "ejgv-tur-aloj" %}
{% trans "ejgv-tur-infos" %}
{% trans "Consultrans" %}
{% trans "dfa" %}
{% trans "dfb" %}
{% trans "dfg" %}
{% trans "fekoor" %}
{% trans "ETS" %}

{% trans "agi" %}
{% trans "gorrak" %}
{% trans "itxaropena" %}
{% trans "eginaren" %}
{% trans "once" %}
{% trans "fevapas" %}
{% trans "elkartu" %}
{% trans "propio" %}

