{% extends "base.html" %}

{% block main_content %}
<div id="logcnt">
{% block cscontent %}

{% endblock %}
</div>
{% endblock %}

{% block sidebar %}
{% block cssidebar %}
{% endblock %}
{% endblock %}