<div id="searchbox">    
          <!-- Google CSE Search Box Begins -->
          <form id="bigsf" action="{%url gsearch%}">
              <input type="hidden" name="cx" value="002318387713884704423:4pwcgf1wug4" />
              <label for="q">{% trans "Go to..." %}</label> <input id="q" name="q" type="text" />
              <input class="searchbutton" type="submit" name="sa" value="{% trans "Search" %}" />
              <input type="hidden" name="cof" value="FORID:11" />
              <p><a href="/filter/">{% trans "Advanced filter" %}</a></p>
          </form>
          <script type="text/javascript" src="http://www.google.com/coop/cse/brand?form=searchbox_001098326678246934980%3Afr8fiqutrzm"></script>
          <!-- Google CSE Search Box Ends -->
</div>